@@ -43,13 +43,6 @@ class DataForm(QtGui.QMainWindow):
         self.progress = QtGui.QProgressDialog('Please wait...', 
                                               'Stop', 0, 100, self)
         self.progress.setWindowTitle('Generating tables')
-        
-        # This is gives time for UI to show up before updating tables
-        self.timer = QtCore.QBasicTimer()
-        self.timer.start(100, self)
-        
-    def timerEvent(self, event):
-        self.timer.stop()
         self.generate_traffic_tables()
     
     def change_max_rows(self):
@@ -315,7 +308,7 @@ class DataForm(QtGui.QMainWindow):
             table.setRowCount(rows)
         else:
             table.setRowCount(self.max_rows)
-        table.horizontalHeader().resizeSection(0, 300)
+        table.horizontalHeader().resizeSection(0, 315)
         table.horizontalHeader().setVisible(True)
         
     def _set_table_row(self, table, row_number, traffic_row):
